@@ -417,6 +417,8 @@ class TradingCRNCalculator:
             df = df[df['SYMBOL'].str[0].isin(['0', '3', '6'])]
             df.rename(columns={"SYMBOL": "ticker", "TDATE": "tradeDate", "TCAP": "marketValue",
                                "VATURNOVER": "turnoverValue"}, inplace=True)
+            # 剔除停牌、没有成交额的数据
+            df = df[df['turnoverValue'] > 0.]
             quantile_5, quantile_10 = df['turnoverValue'].quantile(0.95), df['turnoverValue'].quantile(0.90)
             cr5 = df[df['turnoverValue'] >= quantile_5]['turnoverValue'].sum() / df['turnoverValue'].sum()
             cr10 = df[df['turnoverValue'] >= quantile_10]['turnoverValue'].sum() / df['turnoverValue'].sum()
@@ -467,7 +469,8 @@ class TradingCRNCalculator:
             legend_opts=opts.LegendOpts(pos_right="center", pos_top='5%'),
             xaxis_opts=opts.AxisOpts(
                 type_='category',
-                axistick_opts=opts.AxisTickOpts(is_show=True),
+                is_inverse=True,
+                axistick_opts=opts.AxisTickOpts(is_show=True, is_align_with_label=True),
                 splitline_opts=opts.SplitLineOpts(is_show=True),
                 axisline_opts=opts.AxisLineOpts(on_zero_axis_index=False),
             ),
@@ -483,17 +486,17 @@ class TradingCRNCalculator:
                 opts.DataZoomOpts(type_="inside")
             ],
         ).add_xaxis(
-            xaxis_data=df['trade_date'].tolist()
+            xaxis_data=df['trade_date'].tolist()[::-1]
         ).add_yaxis(
             series_name="前5%个股成交额集中度",
-            y_axis=df["cr5"].round(1).tolist(),
+            y_axis=df["cr5"].round(1).tolist()[::-1],
             is_symbol_show=False,
             is_smooth=True,
             linestyle_opts=opts.LineStyleOpts(width=1.5),
             label_opts=opts.LabelOpts(is_show=False)
         ).add_yaxis(
             series_name="前10%个股成交额集中度",
-            y_axis=df["cr10"].round(1).tolist(),
+            y_axis=df["cr10"].round(1).tolist()[::-1],
             is_symbol_show=False,
             is_smooth=True,
             linestyle_opts=opts.LineStyleOpts(width=1.5),
@@ -518,7 +521,8 @@ class TradingCRNCalculator:
             legend_opts=opts.LegendOpts(pos_right="center", pos_top='5%'),
             xaxis_opts=opts.AxisOpts(
                 type_='category',
-                axistick_opts=opts.AxisTickOpts(is_show=True),
+                is_inverse=True,
+                axistick_opts=opts.AxisTickOpts(is_show=True, is_align_with_label=True),
                 splitline_opts=opts.SplitLineOpts(is_show=True),
                 axisline_opts=opts.AxisLineOpts(on_zero_axis_index=False),
             ),
@@ -534,10 +538,10 @@ class TradingCRNCalculator:
                 opts.DataZoomOpts(type_="inside")
             ],
         ).add_xaxis(
-            xaxis_data=df['trade_date'].tolist()
+            xaxis_data=df['trade_date'].tolist()[::-1]
         ).add_yaxis(
             series_name="成交额加权市值",
-            y_axis=df["avg_mkt"].round(1).tolist(),
+            y_axis=df["avg_mkt"].round(1).tolist()[::-1],
             is_symbol_show=False,
             is_smooth=True,
             linestyle_opts=opts.LineStyleOpts(width=1.5),
@@ -562,6 +566,8 @@ class TradingCRNCalculator:
                 label_opts=opts.LabelOpts(is_show=False))
         )
 
+        line.render("D:\\kevin\\123.html")
+
         return line.overlap(line2)
 
 
@@ -570,4 +576,4 @@ if __name__ == '__main__':
     # MarketMacro('20120201', '20210323').draw_picture()
     # MarketMicro('20050131', '20210226').draw_picture(direction="right")
     # MarketValuation('20120224', '20210326').draw_picture()
-    TradingCRNCalculator('20190101', '20210330').draw_cr_picture()
+    TradingCRNCalculator('20110101', '20210402').draw_cr_picture()
