@@ -43,6 +43,14 @@ exchange_list = [
     HSJY_EXCHANGE_SHFE
 ]
 
+exchange_dict = {
+    HSJY_EXCHANGE_CFFEX: '中金所',
+    HSJY_EXCHANGE_DCE: '大商所',
+    HSJY_EXCHANGE_INE: '能源所',
+    HSJY_EXCHANGE_CZCE: '郑商所',
+    HSJY_EXCHANGE_SHFE: '上期所'
+}
+
 # 品种代码
 HSJY_PRODUCT_CODE = {
     'IH': 46,
@@ -178,5 +186,10 @@ db = 'readonly'
 db_tables = {
     'hsjy_com_daily_quote': 'HSJY_GG.Fut_DailyQuote'.upper(),
     'hsjy_fin_daily_quote': 'HSJY_GG.Fut_TradingQuote'.upper(),
+    'hsjy_fut_contract_info': 'HSJY_GG.Fut_ContractMain'.upper(),
+    'hsjy_cons_info': 'HSJY_GG.CT_Product'.upper(),
+    'hsjy_product_info': 'HSJY_GG.Fut_FuturesContract'.upper(),
+    'hsjy_wr': 'HSJY_GG.Fut_WRStatByOption'.upper(),
+    'hsjy_member_rank': 'HSJY_GG.FUT_MEMBERRANKBYCONTRACT',
     'ch_stocks_daily_quote': 'FINCHINA.CHDQUOTE',
 }
