@@ -5,7 +5,7 @@ import numpy as np
 from datetime import datetime
 from sqlalchemy import create_engine
 import pymysql
-from hbshare.quant.load_data import load_funds_data
+from hbshare.quant.load_data import load_funds_data, load_funds_alpha, load_calendar_extra
 
 pymysql.install_as_MySQLdb()
 
@@ -52,15 +52,27 @@ def performance_analysis(
             single_df['ret'] = single_df[i] / single_df[i].shift(1) - 1
             single_df['highest'] = single_df[i].cummax()
             single_df['dd'] = (single_df[i] - single_df['highest']) / single_df['highest']
+            single_df['ddd'] = single_df['dd'].apply(lambda x: 1 if x < 0 else 0)
+            single_df['ddds'] = single_df['ddd'].cumsum()
+            single_df['dddg'] = (single_df.index - single_df['ddds']) * single_df['ddd']
             max_dd = min(single_df['dd'])
 
+            dd_days = single_df['dddg'].value_counts().reset_index().sort_values(by='index')
+            if len(dd_days) > 1:
+                dd_days_hist = max(dd_days['dddg'].tolist()[1:])
+                dd_days_now = dd_days['dddg'].tolist()[-1]
+            else:
+                dd_days_hist = np.nan
+                dd_days_now = np.nan
+
             fund_last_days = single_df[date_col][len(single_df) - 1] - single_df[date_col][0]
+            cum_return = single_df[i][len(single_df) - 1] / single_df[i][0] - 1
             annualized_return = (single_df[i][len(single_df) - 1] / single_df[i][0]) ** (365 / fund_last_days.days) - 1
             annualized_return_mean = np.mean(single_df['ret'][1:] + 1) ** ret_num_per_year - 1  # 复利年化
             annualized_return_mean_simple = np.mean(single_df['ret'][1:]) * ret_num_per_year
             annualized_vol = np.std(single_df['ret'][1:], ddof=1) * np.sqrt(ret_num_per_year)
 
-            single_df['downside_risk'] = single_df['ret'] #- risk_free
+            single_df['downside_risk'] = single_df['ret']  #- risk_free
             single_df.loc[
                 single_df['downside_risk'] > ((1 + risk_free) ** (1 / ret_num_per_year) - 1),
                 'downside_risk'
@@ -78,10 +90,14 @@ def performance_analysis(
                 calmar = None
 
             win_rate = sum(single_df['ret'] > 0) / (len(single_df) - 1)
-            win_loss = (
-                    np.average(single_df[single_df['ret'] > 0]['ret'])
-                    / np.average(-single_df[single_df['ret'] < 0]['ret'])
-            )
+
+            if len(single_df[single_df['ret'] < 0]['ret']) > 0:
+                win_loss = (
+                        np.average(single_df[single_df['ret'] > 0]['ret'])
+                        / np.average(-single_df[single_df['ret'] < 0]['ret'])
+                )
+            else:
+                win_loss = np.nan
 
             if i in monthly_funds:
                 annualized_return_mean = np.nan
@@ -91,6 +107,7 @@ def performance_analysis(
                 win_rate = np.nan
                 win_loss = np.nan
         else:
+            cum_return = np.nan
             annualized_return = np.nan
             annualized_return_mean = np.nan
             annualized_return_mean_simple = np.nan
@@ -101,14 +118,19 @@ def performance_analysis(
             calmar = np.nan
             win_rate = np.nan
             win_loss = np.nan
+            dd_days_hist = np.nan
+            dd_days_now = np.nan
 
         result_single = pd.DataFrame(
             {
+                start_date.strftime('%Y%m%d') + '以来累计': cum_return,
                 start_date.strftime('%Y%m%d') + '以来年化': annualized_return,
                 '平均周收益年化': annualized_return_mean,
                 # '平均年化收益(单利)': annualized_return_mean_simple,
                 '年化波动率': annualized_vol,
                 '最大回撤': max_dd,
+                '历史最长回撤周': dd_days_hist,
+                '已回撤周': dd_days_now,
                 'Sharpe': sharpe,
                 'Sortino': sortino,
                 # '收益峰度': single_df['ret'][1:].kurt(),
@@ -352,4 +374,99 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None):
         return result_df.T.reset_index()
 
 
+# 统计汇总
+def update_performance(start_d, end_d, funds, db_path, cal_db_path, month_release, data_type=''):
+    fund_list = pd.read_sql_query(
+        'select * from fund_list where `name` in ' + str(tuple(funds)), create_engine(db_path)
+    )
+
+    nav_origin = None
+
+    if data_type.lower() != 'alpha':
+        funds_data = load_funds_data(
+            fund_list=fund_list, first_date=datetime(2000, 1, 1).date(), end_date=end_d,
+            db_path=db_path, cal_db_path=cal_db_path
+        )
+        funds_data_monthly = load_funds_data(
+            fund_list=fund_list, first_date=start_d, end_date=end_d, freq='month',
+            db_path=db_path, cal_db_path=cal_db_path
+        )
+
+    else:
+        funds_data = load_funds_alpha(
+            fund_list=fund_list, first_date=datetime(2000, 1, 1).date(), end_date=end_d,
+            db_path=db_path, cal_db_path=cal_db_path
+        )
+        nav_origin = funds_data['nav']
+        funds_data = funds_data['eav']
+
+        cal_daily = load_calendar_extra(freq='', end_date=end_d, db_path=cal_db_path)
+        cal_daily = pd.merge(cal_daily, funds_data, on='t_date', how='left')
+        cal_daily = cal_daily.fillna(method='ffill')
+
+        funds_data_monthly = pd.merge(
+            load_calendar_extra(freq='month', end_date=end_d, db_path=cal_db_path),
+            cal_daily,
+            on='t_date', how='left'
+        )
+        funds_data_monthly = funds_data_monthly[funds_data_monthly['t_date'] >= start_d]
+
+    result_monthly_ret = ret(funds_data_monthly)[1:].iloc[::-1]
+    result_key, result_dd, result_ret = performance_analysis(
+        funds_data[funds_data['t_date'] >= start_d].reset_index(drop=True), monthly_funds=month_release
+    )
+
+    result_specific = performance_specific_ret(
+        funds_data[funds_data['t_date'] >= start_d].reset_index(drop=True), monthly_funds=month_release
+    )
+
+    fund_name_list = []
+    fund_date_list = []
+    fund_start_date = []
+    for n in fund_list['name']:
+        fund_name_list.append(n)
+        fund_date_list.append(funds_data[funds_data[n] > 0]['t_date'].tolist()[-1].strftime('%Y-%m-%d'))
+        fund_start_date.append(funds_data[funds_data[n] > 0]['t_date'].tolist()[0].strftime('%Y/%m/%d'))
+
+    result_date = pd.DataFrame(
+        {
+            '净值起始日期': fund_start_date,
+            '最新净值日期': fund_date_list
+        }, index=fund_name_list
+    ).T.reset_index()
+
+    results_all = result_date.append(result_specific).append(result_key)
+
+    nav_all = funds_data
+
+    dd_all = result_dd
+
+    weekly_ret_all = result_ret
+
+    monthly_ret_all = result_monthly_ret
+
+    nav_all_origin = nav_origin
+
+    nav_2019 = nav_all[np.array(nav_all['t_date'] >= datetime(2018, 12, 28).date())].copy()
+    nav_2020 = nav_all[np.array(nav_all['t_date'] >= datetime(2019, 12, 27).date())].copy()
+
+    funds = nav_all.columns.tolist()
+    funds.remove('t_date')
+
+    for i in funds:
+        nav_2019.loc[:, i] = nav_2019[i] / nav_2019[nav_2019[i] > 0][i].tolist()[0]
+        nav_2020.loc[:, i] = nav_2020[i] / nav_2020[nav_2020[i] > 0][i].tolist()[0]
+
+    result = {
+        'main': results_all,
+        'nav2020': nav_2020.sort_values(by='t_date', ascending=False).reset_index(drop=True),
+        'nav2019': nav_2019.sort_values(by='t_date', ascending=False).reset_index(drop=True),
+        'nav': nav_all.sort_values(by='t_date', ascending=False).reset_index(drop=True),
+        'dd': dd_all.sort_values(by='t_date', ascending=False).reset_index(drop=True),
+        'weekly_ret': weekly_ret_all.sort_values(by='t_date', ascending=False).reset_index(drop=True),
+        'monthly_ret': monthly_ret_all
+    }
+    if data_type == 'alpha':
+        result['nav_o'] = nav_all_origin.sort_values(by='t_date', ascending=False).reset_index(drop=True)
+    return result
 
