@@ -20,7 +20,7 @@ import pymysql
 
 pymysql.install_as_MySQLdb()
 
-page_size_con = 99999
+page_size_con = 49999
 
 
 def trade_calendar(start_date=None, end_date=None, page_size=None):
@@ -279,3 +279,31 @@ def daily_ret_by_vol(start_date=None, end_date=None, ex_list=None, min_vol=10000
 
     return data
 
+
+def fut_com_amount_by_ex(start_date=None, end_date=None, page_size=None):
+
+    ex_list = [
+        HSJY_EXCHANGE_SHFE,
+        HSJY_EXCHANGE_DCE,
+        HSJY_EXCHANGE_CZCE,
+        HSJY_EXCHANGE_INE
+    ]
+    if start_date is None:
+        start_date = datetime(2010, 1, 1).date()
+    if end_date is None:
+        end_date = datetime.now().date()
+    if page_size is None:
+        page_size = page_size_con
+
+    sql_e = 'EXCHANGE in ' + str(tuple(ex_list))
+
+    sql = 'select ENDDATE, SUM(TURNOVER) from ' + db_tables['hsjy_com_daily_quote'] \
+          + ' where ENDDATE<=TRUNC(to_date(' + end_date.strftime('%Y%m%d') \
+          + ', \'yyyymmdd\')) and ENDDATE>=TRUNC(to_date(' + start_date.strftime('%Y%m%d') \
+          + ', \'yyyymmdd\')) and ' + sql_e + ' group by ENDDATE order by ENDDATE'
+    data = hbs.db_data_query(db=db, sql=sql, page_size=page_size)
+    if data['pages'] > 1:
+        for p in range(2, data['pages'] + 1):
+            data['data'] = data['data'] + hbs.db_data_query(db=db, sql=sql, page_size=page_size, page_num=p)['data']
+
+    return data
